audtorch.metrics.functional
===========================

The goal of the metrics functionals is to provide functions that work
independent on the dimensions of the input signal and can be used easily to
create additional metrics and losses.

.. automodule:: audtorch.metrics.functional

pearsonr
--------

.. autofunction:: pearsonr

concordance_cc
--------------

.. autofunction:: concordance_cc

